@@ -21,20 +21,18 @@
 """Main Covalent public functionality."""
 
 import os
+from importlib import metadata
 
-from . import executor
+from . import _file_transfer as fs
+from . import executor, leptons
 from ._dispatcher_plugins import local_dispatch as dispatch
 from ._dispatcher_plugins import local_dispatch_sync as dispatch_sync
+from ._file_transfer import strategies as fs_strategies
 from ._results_manager.results_manager import cancel, get_result, sync
 from ._shared_files.config import get_config, reload_config, set_config
 from ._shared_files.util_classes import RESULT_STATUS as status
-from ._workflow import Lepton, electron, lattice
-
-try:
-    with open(os.path.join(os.path.dirname(os.path.abspath(__file__)), "./VERSION")) as f:
-        __version__ = f.read().strip()
-except FileNotFoundError:
-    pass
+from ._workflow import DepsBash, DepsCall, DepsPip, Lepton, TransportableObject, electron, lattice
+from ._workflow.electron import wait
 
 __all__ = [s for s in dir() if not s.startswith("_")]
 
@@ -42,3 +40,5 @@ for _s in dir():
     if not _s.startswith("_"):
         _obj = globals()[_s]
         _obj.__module__ = __name__
+
+__version__ = metadata.version("covalent")
